==> druid-server-0.23.0-sources.jar: org/apache/druid/curator/ExhibitorConfig.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.druid.curator;

import com.fasterxml.jackson.annotation.JsonProperty;

import javax.validation.constraints.Max;
import javax.validation.constraints.Min;
import java.util.ArrayList;
import java.util.List;

/**
 */
public class ExhibitorConfig
{
  @JsonProperty
  private List<String> hosts = new ArrayList<>();

  @JsonProperty("port")
  @Min(0)
  @Max(0xffff)
  private int restPort = 8080;

  @JsonProperty
  private String restUriPath = "/exhibitor/v1/cluster/list";

  @JsonProperty
  private boolean useSsl = false;

  @JsonProperty
  @Min(0)
  private int pollingMs = 10000;

  public List<String> getHosts()
  {
    return hosts;
  }

  public int getRestPort()
  {
    return restPort;
  }

  public String getRestUriPath()
  {
    return restUriPath;
  }

  public boolean getUseSsl()
  {
    return useSsl;
  }

  public int getPollingMs()
  {
    return pollingMs;
  }

}

==> druid-server-24.0.2-sources.jar: org/apache/druid/curator/ExhibitorConfig.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.druid.curator;

import com.fasterxml.jackson.annotation.JsonProperty;

import javax.validation.constraints.Max;
import javax.validation.constraints.Min;
import java.util.ArrayList;
import java.util.List;

/**
 */
public class ExhibitorConfig
{
  static final String CONFIG_PREFIX = "druid.exhibitor.service";

  @JsonProperty
  private List<String> hosts = new ArrayList<>();

  @JsonProperty("port")
  @Min(0)
  @Max(0xffff)
  private int restPort = 8080;

  @JsonProperty
  private String restUriPath = "/exhibitor/v1/cluster/list";

  @JsonProperty
  private boolean useSsl = false;

  @JsonProperty
  @Min(0)
  private int pollingMs = 10000;

  public static ExhibitorConfig create(List<String> hosts)
  {
    ExhibitorConfig config = new ExhibitorConfig();
    if (hosts != null) {
      config.hosts = hosts;
    }
    return config;
  }

  public List<String> getHosts()
  {
    return hosts;
  }

  public int getRestPort()
  {
    return restPort;
  }

  public String getRestUriPath()
  {
    return restUriPath;
  }

  public boolean getUseSsl()
  {
    return useSsl;
  }

  public int getPollingMs()
  {
    return pollingMs;
  }
}
